.. _psrfits:

*************************************
PSRFITS (`baseband_tasks.io.psrfits`)
*************************************

`~baseband_tasks.io.psrfits` contains interfaces for PSRFITS data.

.. _psrfits_api:

Reference/API
=============

.. automodapi:: baseband_tasks.io.psrfits
   :no-inherited-members:
